function [ d ] = haversine( c1,c2 )
% Computes the shortest distance between to GPS coordinates.
% Input args:
% c1,c2: The two coordinates, each is a [lat lon] pair.
% Output args:
% d: distance between the two points.

if numel(c1)==numel(c2)&&numel(c2)==2
    if size(c1,2)~=2
        c1=c1';
    end
    if size(c2,2)~=2
        c2=c2';
    end
else
    error('Expected lat lon pair for each coordinate.');
end

lat=[c1(1,1) c2(1,1)].*2*pi/360; % Latitudes.
lon=[c1(1,2) c2(1,2)].*2*pi/360; % Longitudes
dlat=(lat(1,1)-lat(1,2)); % Difference in latitude.
dlon=(lon(1,1)-lon(1,2)); % Difference in longitude.
Re=6.371e6; % Mean radius of Earth.

% The Haversine formula:

a=(sin(dlat/2))^2+cos(lat(1,1))*cos(lat(1,2))*((sin(dlon/2))^2);
c=2*atan2(sqrt(a),sqrt(1-a));
d=Re*c;

end

